![Screenshot_20210827-111909-removebg-preview](https://user-images.githubusercontent.com/74001397/131107876-db415339-0c1d-4876-8665-fe9b76c4518c.png)

oxDork uses Google dorking techniques and Google dorks to find security holes and misconfigurations in web servers.

![Python Version](https://img.shields.io/badge/python-3.x-blue?style=for-the-badge&logo=python)
![OS](https://img.shields.io/badge/OS-GNU%2FLinux-red?style=for-the-badge&logo=linux)
![GitHub](https://img.shields.io/github/license/rly0nheart/oxdork?style=for-the-badge&logo=github)
![CodeFactor](https://www.codefactor.io/repository/github/rly0nheart/oxdork/badge?style=for-the-badge&logo=codefactor)
![GitHub release (latest by date including pre-releases)](https://img.shields.io/github/v/release/rly0nheart/oxdork?include_prereleases&style=for-the-badge&logo=github)
![GitHub repo size](https://img.shields.io/github/repo-size/rly0nheart/oxdork?style=for-the-badge&logo=github)

![oxdork](https://user-images.githubusercontent.com/74001397/156899717-538333bd-934c-4d3e-a30e-0f87c7389ddd.gif)

# Installation
```
$ pip install oxdork
```

# Usage
```
$ oxdork [query]
```

# Updating
```
$ pip install --upgrade oxdork
```

# Optional Arguments

| Flag           | MetaVar | Usage |
| ------------- |:----------------------:|:---------:|
| <code>-u/--update</code>    ||  update oxdork |
| <code>-m/--minimal</code>    || initiate a minimal alternative of oxdork |
| <code>-c/--count</code>    | *number* |  number of dork results to return (default is 10) |
| <code>-d/--dump</code>      |   *path/to/file* |  write output to a specified file  |
| <code>-v/--verbose</code>      |    |  enable verbosity (recommended)  |



# Note(s):
> *Use VPN for better experience.*

> *Sending more than 5 requests in less than 5 minutes will return a 429 error code. If this happens you can pass the -m/--minimal argument instead.*

# Github
View source code on [Github](https://github.com/rly0nheart/oxdork)

# Queries
A collection of 5,568 common dork queries [here](https://github.com/rly0nheart/oxdork/tree/master/dork_queries)

# About author
* [About.me](https://about.me/rly0nheart)